==> decibel-audio-player_0.09.orig.tar.gz: decibel-audio-player-0.09/src/media/mp4.py <==
# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import media

from tools       import consts
from mutagen.mp4 import MP4


def readInfo(file):
    """ Read information from a mp4 file """
    mp4File = MP4(file)

    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(mp4File.info.length)), file]

    try:    info[media.NFO_NUM] = mp4File['trkn'][0][0]
    except: pass

    try:    info[media.NFO_TIT] = unicode(str(mp4File['\xa9nam'][0]), errors='replace')
    except: pass

    try:    info[media.NFO_ALB] = unicode(str(mp4File['\xa9alb'][0]), errors='replace')
    except: pass

    try:    info[media.NFO_ART] = unicode(str(mp4File['\xa9ART'][0]), errors='replace')
    except: pass

    return info

==> decibel-audio-player_0.10.orig.tar.gz: decibel-audio-player-0.10/src/media/mp4.py <==
# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import media

from tools       import consts
from mutagen.mp4 import MP4


def readInfo(file):
    """ Read information from a mp4 file """
    mp4File = MP4(file)

    info = [consts.UNKNOWN_TRACKNUMBER, consts.UNKNOWN_TITLE, consts.UNKNOWN_ARTIST, consts.UNKNOWN_ALBUM, int(round(mp4File.info.length)), file, consts.UNKNOWN_ALBUM_ARTIST]

    try:    info[media.NFO_NUM] = mp4File['trkn'][0][0]
    except: pass

    try:    info[media.NFO_TIT] = unicode(str(mp4File['\xa9nam'][0]), errors='replace')
    except: pass

    try:    info[media.NFO_ALB] = unicode(str(mp4File['\xa9alb'][0]), errors='replace')
    except: pass

    try:    info[media.NFO_ART] = unicode(str(mp4File['\xa9ART'][0]), errors='replace')
    except: pass

    try:    info[media.NFO_AAR] = unicode(str(mp4File['aART'][0]), errors='replace')
    except: pass

    return info
